

// this comes from the seisplotjs waveformplot bundle
var wp = seisplotjs_waveformplot


/** create seismogram plots by selecting elements using the supplied
  * css selector. Each element is expected to have attributes defined
  * for net, sta, loc, chan and two of start, end and duration.
  * Optionally, end will default to NOW if neither start or end are
  * given, so only giving duration shows the most recent duration seconds
  * from current time. Optionally, host may be given to choose an Fdsn
  * FDSN dataselect web service for data retrieval, which defaults to
  * service.iris.edu.
  * This expects only one element to match the selector. The NSLC can 
  * include wildcards and thus multiple plots one for each channel will be created.
  * Previously rendered waveforms are cleared, a download link is provided 
  * to resubmit request to the webservice to download the miniseed file. 
  * Note that the download link sends a separate request with the exact same
  * parameters as the waveform request, but the response can be different 
  * based on sample rate, packet size, buffer size, archival size, 
  * user time vs NTP time. 
  * Note that css style for the waveform selector 'myseisplot' should set 
  * both stroke to a color and fill to none in order for the seismogram to display. 
  * This can be done by: 
  * myseisplot {
  *   stroke: skyblue;
  *   fill: none;
  * }
  */


$('#id_displaywf').click(function() {
console.log("in button pressed");

    var dur = $('#id_duration').val();
    if (dur == null) {
        dur = 300;
    }
    //Limit duration to 1 hour
    if (dur > 3600) {
        $('#div_id_duration').append('<p class="error">Duration is limited to 3600 seconds. Please select a number <= 3600</p>');
        return;
  
    }
    var host = $('#id_host').val();
    if (host == null) {
        host = 'service.iris.edu';
    }
  
    var snclarr = $('#id_sncl').val().split('.');
    var net = snclarr[0];
    var sta = snclarr[1];
    var loc = snclarr[2];
    var chan = snclarr[3];
  
    var divs = wp.d3.select('div.data');
//don't need to do this, can just create the plot directly
//    divs.attr('duration', dur);
//    divs.attr('host', host);
//    divs.attr('net', snclarr[0]);
//    divs.attr('sta', snclarr[1]);
//    divs.attr('loc', snclarr[2]);
//    divs.attr('chan', snclarr[3]);
  
    var protocol = 'http:';
    if ("https:" == document.location.protocol) {
      protocol = 'https:'
    }

    divs.html("");
    var clockOffset = 0; // set this from server somehow!!!!
    var seisDates = wp.calcStartEndDates(null, null, dur, clockOffset);
    var startDate = seisDates.start;
    var endDate = seisDates.end;
    
console.log("Start end: "+startDate+" "+endDate);
    var url = wp.formRequestUrl(protocol, host, net, sta, loc, chan, startDate, endDate);
    divs.append('div').attr('class', 'form-row')
        .append('a').attr('href', url).html('Download miniseed file');

    wp.loadParse(url, function (error, dataRecords) {
      if (error) {
        divs.append('p').html("Error loading data." );
      } else {
          var byChannel = wp.miniseed.byChannel(dataRecords);
          var keys = Object.keys(byChannel);
          for (var i = 0; i < keys.length; i++) {
            var key = keys[i];
            var segments = wp.miniseed.merge(byChannel[key]);
            divs.append('p').html('Plot for ' + key);
            var svgdiv = divs.append('div').attr('class', 'myseisplot');
            if (segments.length > 0) {
                var seismogram = new wp.chart(svgdiv, segments, startDate, endDate);
                seismogram.draw();
            }
        }
        if (keys.length==0){
            divs.append('p').html('No data found');
        }
      }
    });

});
